# coding: utf-8
# flake8: noqa
from os.path import join

from nbconvert.exporters.export import exporter_map

from .exporters.html import PresentExporter
from ._version import __version__, __version_info__


PDFPresentExporter = None
pdf_import_error = None

try:
    from .exporters.pdf import PDFPresentExporter
except Exception as err:
    pdf_import_error = err


# Jupyter Extension points
def _jupyter_nbextension_paths():
    return [dict(
        section="notebook",
        src=join("static", "nbpresent"),
        dest="nbpresent",
        require="nbpresent/js/nbpresent.min")]


def _jupyter_server_extension_paths():
    return [dict(module="nbpresent")]


# serverextension
def load_jupyter_server_extension(nbapp):
    nbapp.log.info("✓ nbpresent HTML export ENABLED")
    exporter_map.update(
        nbpresent=PresentExporter,
    )

    if pdf_import_error:
        nbapp.log.warn(
            "✗ nbpresent PDF export DISABLED: {}"
            .format(pdf_import_error)
        )
    else:
        nbapp.log.info("✓ nbpresent PDF export ENABLED")
        exporter_map.update(
            nbpresent_pdf=PDFPresentExporter
        )



from subprocess import Popen
import sys

from ._env import (
    CSS,
    SRC,
    IS_WIN,
    join,
    node_bin,
)


def main(**opts):
    args = [
        node_bin("lessc"),
        "--autoprefix",
        "--clean-css",
        "--include-path={}".format(node_bin("..")),
        join(SRC, "less", "index.less"),
        join(CSS, "nbpresent.min.css")
    ] + opts.get("less", [])
    return Popen(args, shell=IS_WIN).wait()


if __name__ == "__main__":
    sys.exit(main())



import sys
import shutil

from ._env import (
    JS,
    SRC,
    join,
)


def main(**opts):
    shutil.copyfile(
        join(SRC, "js", "index.js"),
        join(JS, "nbpresent.min.js")
    )
    return 0

if __name__ == "__main__":
    sys.exit(main())



from os.path import (
    dirname,
    abspath,
    join,
)
import platform


PKG = "nbpresent"

REPO_ROOT = abspath(join(dirname(__file__), "..", ".."))
PKG_ROOT = join(REPO_ROOT, PKG)
SRC = join(REPO_ROOT, "src")
DIST = join(PKG_ROOT, "static", PKG)
JS = join(DIST, "js")
CSS = join(DIST, "css")

IS_WIN = "Windows" in platform.system()


def node_bin(*it):
    return join(REPO_ROOT, "node_modules", ".bin", *it)


def external(*modules):
    # browserify --external
    return sum([["--external", m] for m in modules], [])

transform = [
    "--transform", "[", "babelify", "--sourceMapRelative", ".", "]",
]

extension = ["--extension", "es6"]
